@@ -110,6 +110,8 @@ struct _NautilusNavigationWindowDetails {
         gboolean temporary_location_bar;
         gboolean temporary_search_bar;
 
+        GtkWidget *location_button;
+
         /* Side Pane */
         int side_pane_width;
         NautilusSidebar *current_side_panel;
@@ -121,7 +123,6 @@ struct _NautilusNavigationWindowDetails {
         
         /* Toolbar */
         GtkWidget *toolbar;
-        GtkTooltips *tooltips;
         GtkWidget *location_bar;
 
         guint extensions_toolbar_merge_id;
@@ -186,7 +187,7 @@ void               nautilus_menus_append_bookmark_to_menu                (Nautil
                                                                           guint              merge_id,
                                                                           GCallback          refresh_callback,
                                                                           NautilusBookmarkFailedCallback failed_callback);
-#if NEW_UI_COMPLETE
+#ifdef NEW_UI_COMPLETE
 void               nautilus_window_go_up                                 (NautilusWindow    *window);
 #endif
 void               nautilus_window_update_find_menu_item                 (NautilusWindow    *window);
